#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from foundry.v2.admin.models._certificate_info_dict import CertificateInfoDict


class SamlServiceProviderMetadataDict(TypedDict):
    """Information that describes a Foundry Authentication Provider as a SAML service provider. All information listed here is generated by Foundry."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    entityId: str
    """The static SAML entity ID that represents this service provider."""

    metadataUrl: str
    """A public URL from which this service provider metadata can be downloaded as XML."""

    acsUrls: List[str]
    """
    The Assertion Consumer Service (ACS) URLs for this service provider, to which the SAML identity provider
    redirects authentication responses.
    """

    logoutUrls: List[str]
    """The URLs for this service provider to which the SAML identity provider sends logout requests."""

    certificates: List[CertificateInfoDict]
